# autodora
autodora is a framework to help you:
1. setup experiments
2. running them for multiple parameters
3. storing the results
4. exploring the results

The aim of this package is to make these steps as easy and integrated as possible.

## Installation

    pip install autodora